# JTRFaker

The `JTRFaker` domain is a utility module in your project that is primarily focused on generating
fake data for testing and development purposes. It leverages the power of the Faker library to
create realistic yet random data that can be used to populate your database during `development`
or for `testing` your application's functionality.

## Installation

```bash
pip install JTRFaker
```

## Usage

The usage varies depending on the type of data you want to generate. The following are the
different types of data that can be generated using the `JTRFaker` module:

1. `ModelFaker` - Database entries based on sqlalchemy models with lots of different options. 
